@@ -39,7 +39,7 @@ class SpecificationTypeParser:
             for attribute_definition in xml_spec_attributes:
                 long_name = attribute_definition.attrib["LONG-NAME"]
                 identifier = attribute_definition.attrib["IDENTIFIER"]
-                description: Optional[str] = (
+                attribute_description: Optional[str] = (
                     attribute_definition.attrib["DESC"]
                     if "DESC" in attribute_definition.attrib
                     else None
@@ -122,11 +122,9 @@ class SpecificationTypeParser:
                 else:
                     raise NotImplementedError(attribute_definition) from None
                 attribute_definition = SpecAttributeDefinition(
-                    children_tags=list(
-                        map(lambda el: el.tag, list(attribute_definition))
-                    ),
+                    xml_node=attribute_definition,
                     attribute_type=attribute_type,
-                    description=description,
+                    description=attribute_description,
                     identifier=identifier,
                     last_change=last_change,
                     datatype_definition=datatype_definition,
